;FD_prediction.pro
;
;procedure for calculating possible FD ranges and exact FD level based on the 4-bin probability distribution for FD.
;FD ranges and exact FD levels are determined using empirically obtained threshold parameters.
;
;The procedure needs two arrays as an input: p_c and thresholds:
;
;p_c
;1x4 array of input variables:
;column 1: probability for FD < 1%
;column 2: probability for 1% < FD < 3%
;column 3: probability for 3% < FD < 6%
;column 4: probability for FD > 6%
;If p_c is unknown, it should be put p_c=fltarr(4), the procedure then sends out a warning.
;
;thresholds
;=5x1 array of threshold parameters:
;column 1: T1 threshold for P(k=3)
;column 2: T2 threshold for P(k=2)
;column 3: T3 threshold for P(k=0)
;column 4: T4 threshold for P(k=1)
;column 5: T5 threshold for P(k=1)
;
;The output is an integer denoting the expected FD range:
;FD_expected=0: FD < 1%
;FD_expected=1: 1% < FD < 3%
;FD_expected=2: 3% < FD < 6%
;FD_expected=3: FD > 6%
;
;*****************************************************************************************************************************************************************
;

PRO FD_prediction, p_c, thresholds, FD_expected


FD_expected=0
FD_range=make_array(1,3,/float)
FD_range_mean=0.0


;applying thresholds - stage 1 (k=0,1 or k=2,3)
case 1 of
(p_c(0) GT thresholds(0,0)): FD_range(0)=0
else: FD_range(0)=1
endcase

case 1 of
(p_c(1) GT thresholds(1,0)): FD_range(1)=0
else: FD_range(1)=1
endcase

case 1 of
(p_c(2) LT thresholds(2,0)): FD_range(2)=0
else: FD_range(2)=1
endcase

FD_range_mean=(FD_range(0)+FD_range(1)+FD_range(2))/3
check=0.0
check=2.0/3.0

;applying thresholds - stage 2 (calculating expected FD range)
if  (FD_range_mean lt check) then begin
     case 1 of
     (p_c(1) GT thresholds(3,0)): FD_expected=0
     else: FD_expected=1
     endcase
endif else begin
     case 1 of
     (p_c(3) LT thresholds(4,0)): FD_expected=2
     else: FD_expected=3
     endcase
endelse

end